Packages — snptools version 1.0.8 documentation

# Packages

List of packages and modules that are included in the library.

- Finalreport package
  - `FinalReport`
- Format package
  - `Snp`
  - `make_fam()`
  - `make_lgen()`
  - `make_map()`
  - `make_ped()`
- Parentage package
  - `Discovery`
  - `Verification`
  - `isag_disc()`
  - `isag_verif()`
- Statistics package
  - `allele_freq()`
  - `call_rate()`
  - `hwe()`
  - `hwe_test()`
  - `minor_allele_freq()`